| Title: | Repbox Direct Replication Format |
|---|---|
| Description: | Tools to transform a Stata reproduction package into a format that facilitates direct replications of regressions in Stata or R. Key idea is to identify data modification steps, determine which can be translated to R. |
| Authors: | Sebastian Kranz [aut, cre] |
| Maintainer: | Sebastian Kranz <[email protected]> |
| License: | GPL >= 2.0 |
| Version: | 0.1.0 |
| Built: | 2026-06-05 20:00:24 UTC |
| Source: | https://github.com/repboxr/repboxDRF |